@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20725 $
+ * $Revision: 21137 $
  * $Author: ms30002000 $
- * $Date: 2008-08-22 18:21:16 +0000 (Fri, 22 Aug 2008) $
+ * $Date: 2008-09-22 16:57:19 +0000 (Mon, 22 Sep 2008) $
  */
 
 #ifndef _PIPSOCKET
@@ -146,7 +146,7 @@ class PIPSocket : public PSocket
         bool operator==(u_long u) const { return  operator==((DWORD)u); }
         bool operator!=(u_long u) const { return !operator==((DWORD)u); }
 #endif
-#ifdef __BEOS__
+#ifdef P_BEOS
         bool operator==(in_addr_t a) const { return  operator==((DWORD)a); }
         bool operator!=(in_addr_t a) const { return !operator==((DWORD)a); }
 #endif
