@@ -7,9 +7,9 @@
  *
  * Contributor(s): Snark at GnomeMeeting
  *
- * $Revision: 20385 $
- * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Revision: 20850 $
+ * $Author: ms30002000 $
+ * $Date: 2008-09-04 16:51:58 +0000 (Thu, 04 Sep 2008) $
  */
 
 #ifndef _PLUGINMGR_H
@@ -77,6 +77,9 @@ class PPluginManager : public PObject
     // function to register a service (used by the plugins themselves)
     PBoolean RegisterService (const PString & serviceName, const PString & serviceType, PPluginServiceDescriptor * descriptor);
 
+    // Add a directory to the list of plugin directories (used by OPAL)
+    static void AddPluginDirs(PString dirs);
+
     // Get the list of plugin directories
     static PStringArray GetPluginDirs();
 
@@ -109,6 +112,7 @@ class PPluginManager : public PObject
       const PNotifier & filterFunction
     );
 
+    static PString additionalPluginDirs;
   protected:
     void LoadPluginDirectory (const PDirectory & directory, const PStringList & suffixes);
     void CallNotifier(PDynaLink & dll, INT code);
