@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20492 $
+ * $Revision: 21069 $
  * $Author: rjongbloed $
- * $Date: 2008-06-25 01:36:32 +0200 (mer 25 jun 2008) $
+ * $Date: 2008-09-18 22:59:00 +0000 (Thu, 18 Sep 2008) $
  */
 
 #ifndef _PTHREAD
@@ -178,11 +178,14 @@ class PThread : public PObject
     virtual PBoolean IsTerminated() const;
 
     /** Block and wait for the thread to terminate.
-
-       @return
-       #PFalse if the thread has not terminated and the timeout has expired.
      */
     void WaitForTermination() const;
+
+    /** Block and wait for the thread to terminate.
+
+       @return
+       #PFalse if the thread has not terminated and the timeout has expired, #PTrue otherwise.
+     */
     PBoolean WaitForTermination(
       const PTimeInterval & maxWait  ///< Maximum time to wait for termination.
     ) const;
