@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20724 $
+ * $Revision: 21305 $
  * $Author: rjongbloed $
- * $Date: 2008-08-22 13:23:04 +0200 (ven 22 aoû 2008) $
+ * $Date: 2008-10-13 07:02:42 +0000 (Mon, 13 Oct 2008) $
  */
 
 //////////////////////////////////////////////////
@@ -100,13 +100,25 @@ PInterfaceMonitor & PInterfaceMonitor::GetInstance()
 }
 
 
+void PInterfaceMonitor::SetRefreshInterval (unsigned refresh)
+{
+  refreshInterval = refresh;
+}
+
+
+void PInterfaceMonitor::SetRunMonitorThread(bool _runMonitorThread)
+{
+  runMonitorThread = _runMonitorThread;
+}
+
+
 bool PInterfaceMonitor::Start()
 {
   PWaitAndSignal m(mutex);
   
   if (runMonitorThread && updateThread != NULL)
     return false; // Already running
-
+    
   PIPSocket::GetInterfaceTable(currentInterfaces);
   PTRACE(4, "IfaceMon\tInitial interface list:\n" << setfill('\n') << currentInterfaces << setfill(' '));
 
@@ -458,9 +470,9 @@ bool PMonitoredSockets::CreateSocket(SocketInfo & info, const PIPSocket::Address
     natMethod->GetServerAddress(address, port);
     if (PInterfaceMonitor::GetInstance().IsValidBindingForDestination(binding, address)) {
       if (natMethod->CreateSocket(info.socket, binding, localPort)) {
-        PTRACE(4, "MonSock\tCreated bundled UDP socket via " << natMethod->GetName() << " internal="
-               << binding << ':' << info.socket->PUDPSocket::GetPort()
-               << " external=" << info.socket->GetLocalAddress());
+        info.socket->PUDPSocket::GetLocalAddress(address, port);
+        PTRACE(4, "MonSock\tCreated bundled UDP socket via " << natMethod->GetName()
+               << ", internal=" << address << ':' << port << ", external=" << info.socket->GetLocalAddress());
         return true;
       }
     }
@@ -737,6 +749,8 @@ PBoolean PMonitoredSocketChannel::Write(const void * buffer, PINDEX length)
 
 void PMonitoredSocketChannel::SetInterface(const PString & iface)
 {
+  mutex.Wait();
+
   PIPSocket::InterfaceEntry info;
   if (socketBundle != NULL && socketBundle->GetInterfaceInfo(iface, info))
     currentInterface = MakeInterfaceDescription(info);
@@ -745,15 +759,26 @@ void PMonitoredSocketChannel::SetInterface(const PString & iface)
 
   if (lastReceivedInterface.IsEmpty())
     lastReceivedInterface = currentInterface;
+
+  mutex.Signal();
 }
 
 
-const PString & PMonitoredSocketChannel::GetInterface()
+PString PMonitoredSocketChannel::GetInterface()
 {
+  PString iface;
+
+  mutex.Wait();
+
   if (currentInterface.Find('%') == P_MAX_INDEX)
     SetInterface(currentInterface);
 
-  return currentInterface;
+  iface = currentInterface;
+  iface.MakeUnique();
+
+  mutex.Signal();
+
+  return iface;
 }
 
 
@@ -787,6 +812,7 @@ void PMonitoredSocketChannel::SetRemote(const PString & hostAndPort)
 PMonitoredSocketBundle::PMonitoredSocketBundle(bool reuseAddr, PNatMethod * natMethod)
   : PMonitoredSockets(reuseAddr, natMethod)
 {
+  PTRACE(4, "MonSock\tCreated socket bundle for all interfaces.");
 }
 
 
@@ -865,7 +891,7 @@ void PMonitoredSocketBundle::OpenSocket(const PString & iface)
   SocketInfo info;
   if (CreateSocket(info, binding)) {
     if (localPort == 0)
-      localPort = info.socket->GetPort();
+      info.socket->PUDPSocket::GetLocalAddress(binding, localPort);
     socketInfoMap[iface] = info;
   }
 }
@@ -1002,6 +1028,7 @@ PSingleMonitoredSocket::PSingleMonitoredSocket(const PString & _theInterface, bo
   : PMonitoredSockets(reuseAddr, natMethod)
   , theInterface(_theInterface)
 {
+  PTRACE(4, "MonSock\tCreated monitored socket for interfaces " << _theInterface);
 }
 
 
