@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
- * $Author: rjongbloed $
- * $Date: 2008-06-04 10:40:38 +0000 (Wed, 04 Jun 2008) $
+ * $Revision: 21361 $
+ * $Author: csoutheren $
+ * $Date: 2008-10-16 04:47:14 +0000 (Thu, 16 Oct 2008) $
  */
 
 #ifdef __GNUC__
@@ -386,7 +386,7 @@ class PVideoOutputDevice_YUVFile_PluginServiceDescriptor : public PDevicePluginS
     }
     virtual bool ValidateDeviceName(const PString & deviceName, int /*userData*/) const
     {
-        return (deviceName.Right(4) *= ".yuv") && PFile::Access(deviceName, PFile::WriteOnly);
+      return (deviceName.Right(4) *= ".yuv") && (!PFile::Exists(deviceName) || PFile::Access(deviceName, PFile::WriteOnly));
     }
 } PVideoOutputDevice_YUVFile_descriptor;
 
