@@ -24,9 +24,9 @@
  * Contributor(s): ______________________________________.
  *                 Walter H Whitlock (twohives@nc.rr.com)
  *
- * $Revision: 20673 $
- * $Author: dsandras $
- * $Date: 2008-08-17 13:55:51 +0200 (dim 17 aoû 2008) $
+ * $Revision: 21353 $
+ * $Author: csoutheren $
+ * $Date: 2008-10-16 00:33:55 +0000 (Thu, 16 Oct 2008) $
  */
 
 #include <ptlib.h>
@@ -45,6 +45,10 @@
 #endif
 #endif
 
+namespace PWLibStupidLinkerHacks {
+   int loadVideoForWindowsStuff;
+};
+    
 #ifdef __MINGW32__
 
 #define VHDR_DONE       0x00000001
@@ -1004,8 +1008,8 @@ PBoolean PVideoInputDevice_VideoForWindows::InitialiseCapture()
   capPreview(hCaptureWindow, PFalse);
 
 #if PTRACING
-  if (PTrace::CanTrace(6))
-    TestAllFormats(); // list acceptable formats and frame resolutions for video capture driver
+  //if (PTrace::CanTrace(6))
+  //  TestAllFormats(); // list acceptable formats and frame resolutions for video capture driver
 #endif
   
   return SetFrameRate(frameRate) && SetColourFormatConverter(colourFormat.IsEmpty() ? PString("YUV420P") : colourFormat);
@@ -1147,6 +1151,7 @@ class PVideoOutputDevice_Window : public PVideoOutputDeviceRGB
 
   protected:
     PDECLARE_NOTIFIER(PThread, PVideoOutputDevice_Window, HandleDisplay);
+    void SetWindowSize();
     void Draw(HDC hDC);
 
     HWND       m_hWnd;
@@ -1358,17 +1363,24 @@ PBoolean PVideoOutputDevice_Window::SetFrameSize(unsigned width, unsigned height
   }
 
   // Must be outside of mutex
-  if (m_hWnd != NULL) {
-    RECT rect;
-    rect.top = 0;
-    rect.left = 0;
-    rect.bottom = frameHeight;
-    rect.right = frameWidth;
-    ::AdjustWindowRectEx(&rect, GetWindowLong(m_hWnd, GWL_STYLE), PFalse, 0L);
-    ::SetWindowPos(m_hWnd, NULL, 0, 0, rect.right-rect.left, rect.bottom-rect.top, SWP_NOMOVE|SWP_NOZORDER);
-  }
+  SetWindowSize();
 
-  return PTrue;
+  return true;
+}
+
+
+void PVideoOutputDevice_Window::SetWindowSize()
+{
+  if (m_hWnd == NULL)
+    return;
+
+  RECT rect;
+  rect.top = 0;
+  rect.left = 0;
+  rect.bottom = frameHeight;
+  rect.right = frameWidth;
+  ::AdjustWindowRectEx(&rect, GetWindowLong(m_hWnd, GWL_STYLE), false, GetWindowLong(m_hWnd, GWL_EXSTYLE));
+  ::SetWindowPos(m_hWnd, NULL, 0, 0, rect.right-rect.left, rect.bottom-rect.top, SWP_NOMOVE|SWP_NOZORDER);
 }
 
 
@@ -1479,6 +1491,7 @@ void PVideoOutputDevice_Window::HandleDisplay(PThread &, INT)
                           dwStyle,
                           m_lastX, m_lastY, frameWidth, frameHeight,
                           hParent, NULL, GetModuleHandle(NULL), this);
+    SetWindowSize();
   }
 
   m_started.Signal();
