@@ -23,9 +23,9 @@
  *
  * Contributor(s): Matthias Schneider <ma30002000@yahoo.de>
  *
- * $Revision: 20793 $
- * $Author: rjongbloed $
- * $Date: 2008-08-31 09:10:58 +0200 (dim 31 aoû 2008) $
+ * $Revision: 21176 $
+ * $Author: ms30002000 $
+ * $Date: 2008-09-27 20:34:32 +0000 (Sat, 27 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -42,6 +42,11 @@
 #pragma comment(lib, P_DIRECTSHOW_LIBRARY2)
 #endif
 
+#if defined(P_MINGW)
+namespace PWLibStupidLinkerHacks {
+  int loadDirectShowStuff;
+};
+#endif
 
 #define SAFE_RELEASE(p)      { if(p) { (p)->Release(); (p)=NULL; } }
 
@@ -606,7 +611,8 @@ PBoolean PVideoInputDevice_DirectShow::GetFrameDataNoDelay(BYTE *destFrame, PIND
             return PFalse;
         }
 
-        *bytesReturned = cbBuffer;
+        if (bytesReturned != NULL)
+            *bytesReturned = cbBuffer;
 
     }
 
