@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
- * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Revision: 20949 $
+ * $Author: ms30002000 $
+ * $Date: 2008-09-14 09:02:41 +0000 (Sun, 14 Sep 2008) $
  */
 
 #define _OSUTIL_CXX
@@ -85,6 +85,11 @@
 #include <sys/param.h>
 #include <sys/mount.h>
 
+#if defined(P_NETBSD)
+#include <sys/statvfs.h>
+#define statfs statvfs
+#endif
+
 #elif defined(P_HPUX9) 
 #define P_USE_LANGINFO
 
